==> 005-gxp-1.0.4.tgz: package/index.js <==
#!/usr/bin/env node
//创建一个类似于apache的程序
const http = require('http');
const fs = require('fs');
const path = require('path');
const url = require('url');
const getAddress = require('./getAddress');
const childProcess = require('child_process');
const port = 3000;
const tool = require('./tool');
const query = require('querystring');

const server = http.createServer(
    //用户的每一次请求都会调用下面这个函数
    (req,res)=>{
        let file = path.resolve(path.join('.',query.unescape(req.url)));
        if(fs.existsSync(file)){
            if(tool.isFile(file)){
                fs.readFile(file,(err,data)=>{
                    res.end(data);
                })
            }else if(tool.isDirectory(file)){
                let lis = '';
                fs.readdirSync(file).forEach(v=>{
                    lis += `<li>
                                <a href="${path.join(query.unescape(req.url),v)}">
                                    ${v+(tool.isDirectory(path.join(file,v)) ? '/' :    '')}
                                </a>
                            </li>`
                });
                console.log(lis);
                let html = fs.readFileSync(path.join(__dirname,'index.html')).toString();
                res.end(html.replace('$',lis));
            }
        }else{
            res.writeHeader(404);
            res.end();
        }
        //res是一个可写流
        //let ws = fs.createReadStream(path.resolve('./index.html'));
        //ws.pipe(res);
        //ws.on('end',()=>{
        //    console.log(req);
        //    res.end('ok');
        //})

})
server.listen(port,()=>{
    //childProcess.spawnSync('explorer',[url.format({
        //protocol:'http',
        //hostname:getAddress(),
        //port:port,
    //})])
})

==> 005-gxp-1.0.5.tgz: package/index.js <==
#!/usr/bin/env node
//创建一个类似于apache的程序
const http = require('http');
const fs = require('fs');
const path = require('path');
const url = require('url');
const getAddress = require('./getAddress');
const childProcess = require('child_process');
const port = 3000;
const tool = require('./tool');
const query = require('querystring');

const server = http.createServer(
    //用户的每一次请求都会调用下面这个函数
    (req,res)=>{
        let file = path.resolve(path.join('.',query.unescape(req.url)));
        if(fs.existsSync(file)){
            if(tool.isFile(file)){
                fs.readFile(file,(err,data)=>{
                    res.end(data);
                })
            }else if(tool.isDirectory(file)){
                let lis = '';
                fs.readdirSync(file).forEach(v=>{
                    lis += `<li>
                                <a href="${path.join(query.unescape(req.url),v)}">
                                    ${v+(tool.isDirectory(path.join(file,v)) ? '/' :    '')}
                                </a>
                            </li>`
                });
                console.log(lis);
                let html = fs.readFileSync(path.join(__dirname,'index.html')).toString();
                res.end(html.replace('$',lis));
            }
        }else{
            res.writeHeader(404);
            res.end();
        }
        //res是一个可写流
        //let ws = fs.createReadStream(path.resolve('./index.html'));
        //ws.pipe(res);
        //ws.on('end',()=>{
        //    console.log(req);
        //    res.end('ok');
        //})

})
server.listen(port,()=>{
    childProcess.spawnSync('explorer',[url.format({
        protocol:'http',
        hostname:getAddress(),
        port:port,
    })])
})
